@@ -67,7 +67,7 @@ to fill out any elements in the template. It returns the processed template as
 a string. See L<Petal> for further details.
 
 =cut
-our $VERSION   = 0.2;
+our $VERSION   = 0.31;
 
 =head1 FUNCTIONS
 
@@ -145,6 +145,7 @@ sub send
     
     my $mail = $self->process (%args)                    || die '$self->process (\@_) returned undef';
     open (SENDMAIL, "| $Sendmail -f $authorized_sender") || die "error opening sendmail [$Sendmail]: $!";
+    binmode (SENDMAIL, ":utf8");
     print SENDMAIL $mail                                 || die "error writing to sendmail [$Sendmail]: $!";
     close SENDMAIL;
 }
@@ -591,7 +592,7 @@ Probably plenty.
 
 Copyright 2003 - MKDoc Holdings Ltd.
 
-Author: Jean-Michel Hiver <jhiver@mkdoc.com>
+Author: Jean-Michel Hiver
 
 This module is free software and is distributed under the same license as Perl
 itself. Use it at your own risk.
@@ -599,7 +600,7 @@ itself. Use it at your own risk.
 
 =head1 SEE ALSO
 
-  Petal: http://search.cpan.org/author/JHIVER/Petal/
+  Petal: http://search.cpan.org/dist/Petal/
   MKDoc: http://www.mkdoc.com/
 
 Help us open-source MKDoc. Join the mkdoc-modules mailing list:
